@@ -1,5 +1,6 @@
 
 from .schema_qp import SchemaQP
 from .schema_base_config import schema_loglevel
-__all__ = ['SchemaQP', 'schema_loglevel']
+
+__all__ = ['SchemaQP', 'schema_loglevel', 'datasets']
 
